==> scalebox_sdk-0.1.0.tar.gz: scalebox_sdk-0.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Initial release of ScaleBox Python SDK
- Multi-language code execution support (Python, R, Node.js, Deno/TypeScript, Java, Bash)
- Synchronous and asynchronous sandbox execution
- Persistent context management across executions
- Rich result formats (text, HTML, Markdown, SVG, images, LaTeX, JSON, JavaScript, charts)
- Real-time callbacks for stdout, stderr, results, and errors
- Comprehensive test suite with integration tests
- Full API client with authentication support
- File system operations and command execution
- PTY support for interactive sessions
- Context managers for resource cleanup
- Error handling with specific exception types
- Connection configuration with environment variable support

### Features
- **Code Interpreter**: Execute code in multiple languages with rich output formats
- **Sandbox Management**: Create, manage, and destroy isolated execution environments
- **File Operations**: Upload, download, list, and manage files in sandboxes
- **Command Execution**: Run shell commands with real-time output
- **Context Persistence**: Maintain variable state across multiple executions
- **Async Support**: Full async/await support for concurrent operations
- **Error Handling**: Comprehensive exception handling with specific error types
- **Authentication**: API key and token-based authentication
- **Configuration**: Flexible configuration via environment variables or direct parameters

## [0.1.0] - 2025-01-XX

### Added
- Initial release
- Core SDK functionality
- Multi-language support
- Comprehensive documentation
- Test suite with 49+ test cases
- PyPI package configuration

==> scalebox_sdk-0.1.7.tar.gz: scalebox_sdk-0.1.7/CHANGELOG.md <==
# Changelog
## [0.1.7] - 2025-10-10

### Added
- Version 0.1.7 release

### Changed
- Automated version bump (patch)

### Fixed
- Minor improvements and bug fixes


## [0.1.6] - 2025-10-10

### Added
- Version 0.1.6 release

### Changed
- Automated version bump (patch)

### Fixed
- Minor improvements and bug fixes


## [0.1.5] - 2025-10-10

### Added
- Version 0.1.5 release

### Changed
- Automated version bump (patch)

### Fixed
- Minor improvements and bug fixes


## [0.1.4] - 2025-10-10

### Added
- Version 0.1.4 release

### Changed
- Automated version bump (patch)

### Fixed
- Minor improvements and bug fixes


## [0.1.3] - 2025-10-10

### Added
- Version 0.1.3 release

### Changed
- Automated version bump (patch)

### Fixed
- Minor improvements and bug fixes


## [0.1.2] - 2025-10-10

### Added
- Version 0.1.2 release

### Changed
- Automated version bump (patch)

### Fixed
- Minor improvements and bug fixes



All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Initial release of ScaleBox Python SDK
- Multi-language code execution support (Python, R, Node.js, Deno/TypeScript, Java, Bash)
- Synchronous and asynchronous sandbox execution
- Persistent context management across executions
- Rich result formats (text, HTML, Markdown, SVG, images, LaTeX, JSON, JavaScript, charts)
- Real-time callbacks for stdout, stderr, results, and errors
- Comprehensive test suite with integration tests
- Full API client with authentication support
- File system operations and command execution
- PTY support for interactive sessions
- Context managers for resource cleanup
- Error handling with specific exception types
- Connection configuration with environment variable support

### Features
- **Code Interpreter**: Execute code in multiple languages with rich output formats
- **Sandbox Management**: Create, manage, and destroy isolated execution environments
- **File Operations**: Upload, download, list, and manage files in sandboxes
- **Command Execution**: Run shell commands with real-time output
- **Context Persistence**: Maintain variable state across multiple executions
- **Async Support**: Full async/await support for concurrent operations
- **Error Handling**: Comprehensive exception handling with specific error types
- **Authentication**: API key and token-based authentication
- **Configuration**: Flexible configuration via environment variables or direct parameters

## [0.1.0] - 2025-01-XX

### Added
- Initial release
- Core SDK functionality
- Multi-language support
- Comprehensive documentation
- Test suite with 49+ test cases
- PyPI package configuration
